@@ -13,9 +13,10 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with This program.  If not, see <https://www.gnu.org/licenses/>.
+//  along with This program. If not, see <https://www.gnu.org/licenses/>.
 //------------------------------------------------------------------------------
 
+#include <cmath>
 #include <vector>
 #include <Rcpp.h>
 #include "bc_tools.h"
@@ -61,7 +62,7 @@ void calc_features(Rcpp::List& event_data, Rcpp::NumericMatrix& segment, const s
       }
 
       centroid /= sum;
-      cur_peak = round(centroid);
+      cur_peak = std::round(centroid);
     }
 
     if (cur_peak > 0 && prev_peak > 0)
